============
Zuora-Client
============

This is a simple Python client designed to communicate with Zuora in SOAP.

Handle the session, transport and logging parts to make your API calls.

This means that the client is completly agnostic.
